%define	name	opensc
%define version 0.8.1
%define release 8mdk

%define major 0
%define libname %mklibname %{name}

Summary:	Library for accessing SmartCard devices
Name:		%{name}
Version:	%{version}
Release:	%{release}
License:	GPL
Group:		System/Kernel and hardware
URL:		http://www.opensc.org/
Source:		http://www.opensc.org/files/%{name}-%{version}.tar.gz
Patch0:		opensc-0.8.1-parallel-build.patch.bz2
Patch1:		opensc-0.9.6-gcc4.patch
BuildRequires:	automake1.7
BuildRequires:	flex
BuildRequires:	X11-devel
BuildRequires:	openldap-devel >= 2.0
BuildRequires:	libopenct-devel
BuildRequires:	libxslt-proc
# it misdetect openssl, requiring libcrypto.a
BuildRequires:	openssl-static-devel >= 0.9.7a
BuildRequires:	pam-devel
BuildRequires:	readline-devel
BuildRequires:	termcap-devel
BuildRequires:	pcsc-lite-devel
BuildRequires:	libassuan-devel
Requires:	pinentry
Buildroot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
%{name} is a library for accessing smart card devices using PC/SC Lite
middleware package. It is also the core library of the OpenSC project.
Basic functionality (e.g. SELECT FILE, READ BINARY) should work on any
ISO 7816-4 compatible smart card. Encryption and decryption using private
keys on the SmartCard is at the moment possible only with PKCS #15
compatible cards.


%package -n	%{libname}%{major}
Summary:	Library for accessing SmartCard devices
Group:		System/Libraries
License:	LGPL
Provides: 	%{libname} = %{version}-%{release}

%description -n	%{libname}%{major}
%{name} is a library for accessing smart card devices using PC/SC Lite
middleware package. It is also the core library of the OpenSC project.
Basic functionality (e.g. SELECT FILE, READ BINARY) should work on any
ISO 7816-4 compatible smart card. Encryption and decryption using private
keys on the SmartCard is at the moment possible only with PKCS #15
compatible cards.


%package -n	%{libname}%{major}-devel
Summary:	Development related files for %{name}
Group:		Development/C
License:	LGPL
Provides: 	%{libname}-devel = %{version}-%{release}
Provides: 	%{name}-devel = %{version}-%{release}
Requires:	%{libname}%{major} = %{version}

%description -n	%{libname}%{major}-devel
%{name} is a library for accessing smart card devices using PC/SC Lite
middleware package. It is also the core library of the OpenSC project.
Basic functionality (e.g. SELECT FILE, READ BINARY) should work on any
ISO 7816-4 compatible smart card. Encryption and decryption using private
keys on the SmartCard is at the moment possible only with PKCS #15
compatible cards.

This package contains all necessary files to develop or compile any
applications or libraries that use %{name}. 


%package -n	pam_%{name}
Summary:	OpenSC PAM module
Group:		System/Kernel and hardware
Requires:	%{name} = %{version}-%{release}

%description -n	pam_%{name}
This package contains PAM authentication module of OpenSC.

%package -n	mozilla-plugin-%{name}
Summary:	OpenSC Mozilla plugin
Group:		Networking/WWW
Requires:	%{name} = %{version}-%{release}
Requires:	mozilla

%description -n	mozilla-plugin-%{name}
This mozilla plugins handles web signatures using OpenSC
smartcard library.

%prep
%setup -q
%patch0 -p1 -b .parallel
%patch1 -p1 -b .gcc4

AUTOMAKE=automake-1.7 ACLOCAL=aclocal-1.7 autoreconf --force --install

%build
%configure2_5x \
	--with-pin-entry=%{_bindir}/pinentry

%make

%install
rm -rf %{buildroot}
%makeinstall_std

pushd %{buildroot}

# move pam stuff to correct place
mkdir -p %{_lib}/security
mv .%{_libdir}/security/pam*.so %{_lib}/security/
rm -rf .%{_libdir}/security

# move mozilla plugin to correct place
mkdir -p .%{_libdir}/mozilla/plugins
mv .%{_libdir}/opensc/opensc-signer.so .%{_libdir}/mozilla/plugins/

popd

# remove useless files
rm -f %{buildroot}%{_libdir}/pkcs11/*.{a,la} \
      %{buildroot}%{_libdir}/libscam.{a,la} \
      %{buildroot}%{_libdir}/opensc/*.{a,la}

%multiarch_binaries %{buildroot}/%{_bindir}/%{name}-config

%post
%_install_info %{name}.info

%preun
%_remove_install_info %{name}.info

%post -n %{libname}%{major} -p /sbin/ldconfig
%postun -n %{libname}%{major} -p /sbin/ldconfig

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc ANNOUNCE AUTHORS NEWS docs/*.css docs/opensc.html
%doc docs/pkcs-15v1_1.asn etc/*.example
%exclude %{_bindir}/opensc-config
%exclude %{_mandir}/man1/opensc-config*
%{_bindir}/*
%{_datadir}/%{name}
%{_libdir}/pkcs11
%{_libdir}/opensc
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man7/*

%files -n %{libname}%{major}
%defattr(-,root,root)
%doc COPYING
%{_libdir}/lib*.so.*

%files -n %{libname}%{major}-devel
%defattr(-,root,root)
%doc ChangeLog CodingStyle
%exclude %{_libdir}/libscam.so
%multiarch %{_bindir}/opensc-config
%{_libdir}/lib*.so
%{_libdir}/lib*.a
%{_libdir}/lib*.la
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*
%{_mandir}/man1/opensc-config*
%{_mandir}/man3/*

%files -n pam_%{name}
%defattr(-,root,root)
/%{_lib}/security/pam*.so
%{_libdir}/libscam.so

%files -n mozilla-plugin-%{name}
%defattr(-,root,root)
%{_libdir}/mozilla/plugins/*.so

%changelog
* Tue Aug 30 2005 Buchan Milne <bgmilne@linux-mandrake.com> 0.8.1-8mdk
- Rebuild for libldap2.3

* Sun Aug 28 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.8.1-7mdk
- added one gcc4 patch (andreas)

* Mon Feb 07 2005 Buchan Milne <bgmilne@linux-mandrake.com> 0.8.1-6mdk
- rebuild for ldap2.2_7
- fix multiarch

* Sat Jan 22 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 0.8.1-5mdk
- rebuild for new readline

* Thu Dec 02 2004 Abel Cheung <deaddog@mandrake.org> 0.8.1-4mdk
- Fix BuildRequires

* Thu Aug 19 2004 Abel Cheung <deaddog@deaddog.org> 0.8.1-3mdk
- Rebuild
- Enable libtoolize
- P0: Fix parallel build and compatibility with automake > 1.5

* Mon Feb 09 2004 Abel Cheung <deaddog@deaddog.org> 0.8.1-2mdk
- Fix directory ownership

* Tue Oct 14 2003 Abel Cheung <deaddog@deaddog.org> 0.8.1-1mdk
- First Mandrake package

